summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/spinbox2.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/spinbox2.cpp')
-rw-r--r--kalarm/lib/spinbox2.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kalarm/lib/spinbox2.cpp b/kalarm/lib/spinbox2.cpp
index bdd88791..3ec3b68c 100644
--- a/kalarm/lib/spinbox2.cpp
+++ b/kalarm/lib/spinbox2.cpp
@@ -48,8 +48,8 @@ static bool mirrorStyle(const TQStyle&);
int SpinBox2::mReverseLayout = -1;
-SpinBox2::SpinBox2(TQWidget* tqparent, const char* name)
- : TQFrame(tqparent, name),
+SpinBox2::SpinBox2(TQWidget* parent, const char* name)
+ : TQFrame(parent, name),
mReverseWithLayout(true)
{
mUpdown2Frame = new TQFrame(this);
@@ -60,8 +60,8 @@ SpinBox2::SpinBox2(TQWidget* tqparent, const char* name)
init();
}
-SpinBox2::SpinBox2(int minValue, int maxValue, int step, int step2, TQWidget* tqparent, const char* name)
- : TQFrame(tqparent, name),
+SpinBox2::SpinBox2(int minValue, int maxValue, int step, int step2, TQWidget* parent, const char* name)
+ : TQFrame(parent, name),
mReverseWithLayout(true)
{
mUpdown2Frame = new TQFrame(this);
@@ -371,7 +371,7 @@ int SpinBox2::MainSpinBox::shiftStepAdjustment(int oldValue, int shiftStep)
/******************************************************************************
* Repaint the widget.
* If it's the first time since a style change, tell the tqparent SpinBox2 to
* update the SpinMirror with the new unpressed button image. We make the
* presumably reasonable assumption that when a style change occurs, the spin
* buttons are unpressed.
@@ -391,8 +391,8 @@ void ExtraSpinBox::paintEvent(TQPaintEvent* e)
= Class SpinMirror
=============================================================================*/
-SpinMirror::SpinMirror(SpinBox* spinbox, TQFrame* spinFrame, TQWidget* tqparent, const char* name)
- : TQCanvasView(new TQCanvas, tqparent, name),
+SpinMirror::SpinMirror(SpinBox* spinbox, TQFrame* spinFrame, TQWidget* parent, const char* name)
+ : TQCanvasView(new TQCanvas, parent, name),
mSpinbox(spinbox),
mSpinFrame(spinFrame),
mReadOnly(false)
@@ -371,7 +371,7 @@ int SpinBox2::MainSpinBox::shiftStepAdjustment(int oldValue, int shiftStep)
/******************************************************************************
* Repaint the widget.
-* If it's the first time since a style change, tell the tqparent SpinBox2 to
+* If it's the first time since a style change, tell the parent SpinBox2 to
* update the SpinMirror with the new unpressed button image. We make the
* presumably reasonable assumption that when a style change occurs, the spin